ConstantPoolEntry

Enum ConstantPoolEntry 

pub enum ConstantPoolEntry {
Show 17 variants Class { name_index: ConstantPoolIndex, }, FieldRef { class_index: ConstantPoolIndex, name_and_type_index: ConstantPoolIndex, }, MethodRef { class_index: ConstantPoolIndex, name_and_type_index: ConstantPoolIndex, }, InterfaceMethodRef { class_index: ConstantPoolIndex, name_and_type_index: ConstantPoolIndex, }, String { string_index: ConstantPoolIndex, }, Integer { bytes: i32, }, Float { bytes: f32, }, Long { high_bytes: u32, low_bytes: u32, }, Double { high_bytes: u32, low_bytes: u32, }, NameAndType { name_index: ConstantPoolIndex, descriptor_index: ConstantPoolIndex, }, Utf8 { length: u16, bytes: Vec<u8>, }, MethodHandle { reference_kind: u8, reference_index: ConstantPoolIndex, }, MethodType { descriptor_index: ConstantPoolIndex, }, Dynamic { bootstrap_method_attr_index: ConstantPoolIndex, name_and_type_index: ConstantPoolIndex, }, InvokeDynamic { bootstrap_method_attr_index: ConstantPoolIndex, name_and_type_index: ConstantPoolIndex, }, Module { name_index: ConstantPoolIndex, }, Package { name_index: ConstantPoolIndex, },
}

Variants



Class

The CONSTANT_Class_info constant is used to represent a class or an interface. https://docs.oracle.com/javase/specs/jvms/se21/html/jvms-4.html#jvms-4.4.1

Fields



FieldRef

The CONSTANT_Fieldref_info constant is used to represent a reference to a field. https://docs.oracle.com/javase/specs/jvms/se21/html/jvms-4.html#jvms-4.4.2

Fields

class_index: ConstantPoolIndex
name_and_type_index: ConstantPoolIndex


MethodRef

The CONSTANT_Methodref_info constant is used to represent a reference to a method. https://docs.oracle.com/javase/specs/jvms/se21/html/jvms-4.html#jvms-4.4.2

Fields

class_index: ConstantPoolIndex
name_and_type_index: ConstantPoolIndex


InterfaceMethodRef

The CONSTANT_InterfaceMethodref_info constant is used to represent a reference to an interface method. https://docs.oracle.com/javase/specs/jvms/se21/html/jvms-4.html#jvms-4.4.2

Fields

class_index: ConstantPoolIndex
name_and_type_index: ConstantPoolIndex


String

The CONSTANT_String_info constant is used to represent constant objects of the type String https://docs.oracle.com/javase/specs/jvms/se21/html/jvms-4.html#jvms-4.4.3

Fields

string_index: ConstantPoolIndex


Integer

The CONSTANT_Integer_info constant is used to represent 4-byte numeric (int) constants. https://docs.oracle.com/javase/specs/jvms/se21/html/jvms-4.html#jvms-4.4.4

Fields

bytes: i32


Float

The CONSTANT_Float_info constant is used to represent 4-byte floating-point constants. https://docs.oracle.com/javase/specs/jvms/se21/html/jvms-4.html#jvms-4.4.4

Fields

bytes: f32


Long

The CONSTANT_Long_info constant is used to represent 8-byte numeric (long) constants. https://docs.oracle.com/javase/specs/jvms/se21/html/jvms-4.html#jvms-4.4.5

Fields

high_bytes: u32
low_bytes: u32


Double

The CONSTANT_Double_info constant is used to represent 8-byte numeric (double) constants. https://docs.oracle.com/javase/specs/jvms/se21/html/jvms-4.html#jvms-4.4.5

Fields

high_bytes: u32
low_bytes: u32


NameAndType

The CONSTANT_NameAndType_info constant is used to represent a field or method, without indicating which class or interface type it belongs to. https://docs.oracle.com/javase/specs/jvms/se21/html/jvms-4.html#jvms-4.4.6

Fields

descriptor_index: ConstantPoolIndex


Utf8

The CONSTANT_Utf8_info constant is used to represent constant string values. https://docs.oracle.com/javase/specs/jvms/se21/html/jvms-4.html#jvms-4.4.7

Fields

length: u16
bytes: Vec<u8>


MethodHandle

The CONSTANT_MethodHandle_info constant is used to represent a method handle. https://docs.oracle.com/javase/specs/jvms/se21/html/jvms-4.html#jvms-4.4.8

Fields

reference_kind: u8
reference_index: ConstantPoolIndex


MethodType

The CONSTANT_MethodType_info constant is used to represent a method type. https://docs.oracle.com/javase/specs/jvms/se21/html/jvms-4.html#jvms-4.4.9

Fields

descriptor_index: ConstantPoolIndex


Dynamic

The CONSTANT_Dynamic_info constant is used to represent a dynamically-computed constant. https://docs.oracle.com/javase/specs/jvms/se21/html/jvms-4.html#jvms-4.4.10

Fields

bootstrap_method_attr_index: ConstantPoolIndex
name_and_type_index: ConstantPoolIndex


InvokeDynamic

The CONSTANT_InvokeDynamic_info constant is used to represent an invokedynamic call site. https://docs.oracle.com/javase/specs/jvms/se21/html/jvms-4.html#jvms-4.4.10

Fields

bootstrap_method_attr_index: ConstantPoolIndex
name_and_type_index: ConstantPoolIndex


Module

The CONSTANT_Module_info constant is used to represent a module. https://docs.oracle.com/javase/specs/jvms/se21/html/jvms-4.html#jvms-4.4.11

Fields



Package

The CONSTANT_Package_info constant is used to represent a package exported or opened by a module. https://docs.oracle.com/javase/specs/jvms/se21/html/jvms-4.html#jvms-4.4.12

Fields